@@ -4,6 +4,13 @@ from abc import ABCMeta, abstractmethod
 
 
 class Vec(metaclass=ABCMeta):
+    _vector = None
+    _subclass = None
+
+    @abstractmethod
+    def _set_subclass(self):
+        pass
+
     @abstractmethod
     def _set_vec(self, *args, **kwargs):
         pass
@@ -24,41 +31,9 @@ class Vec(metaclass=ABCMeta):
     def _new(self, *args, **kwargs):
         pass
 
-
-class Vec2(Vec):
-    _x, _y = None, None
-    _vector = None
-
-    def __init__(self, x=None, y=0, sub_class=None):
-        if sub_class is None:
-            self._subclass = Vec2
-        else:
-            self._subclass = sub_class
-        if x is None:
-            x = 1
-        self._x = x
-        self._y = y
-
-    @property
-    def x(self):
-        return self._x
-
-    @property
-    def y(self):
-        return self._y
-
-    def _set_vec(self):
-        self._vector = np.array([self._x, self._y], dtype=np.float64)
-
-    def to_array(self):
-        return self._vector
-
-    def _set_xy(self):
-        self._x = self._vector[0]
-        self._y = self._vector[1]
-
-    def _set_xy_and_more(self, *args, **kwargs):
-        self._set_xy()
+    @abstractmethod
+    def angle_between(self, v2):
+        pass
 
     def norm(self):
         return np.linalg.norm(self._vector)
@@ -66,39 +41,24 @@ class Vec2(Vec):
     def angle(self):
         return np.angle(complex(*self._vector[:2]))
 
-    def angle_between(self, v2):
-        return np.arccos(np.dot(
-            self.to_array() / get_norm(self.to_array()),
-            v2 / get_norm(v2)
-        ))
-
-    def __str__(self):
-        return self._vector.__str__()
-
-    def _new(self, x, y):
-        return Vec2(x, y)
-
-    def normalise(self):
-        L = self.norm()
-        self._x /= L
-        self._y /= L
-        self._set_vec()
-        return self
-
     def dot(self, vec):
         if isinstance(vec, self._subclass):
             vec = vec.to_array()
         res = self._vector.dot(vec)
         return res
 
+    def copy(self):
+        return self._new(*self._vector)
+
+    def __str__(self):
+        return self._vector.__str__()
+
     def __add__(self, other):
         if isinstance(other, self._subclass):
             other = other.to_array()
         return self._new(*(self._vector + other))
 
     # 当实现了 __add__, 即使不手动实现__iadd__也是安全的，
-    # python会自动为其分配调用实例， 即可以使用 += 操作。
-    # __sub__, __mul__同理。
     def __iadd__(self, other):
         if isinstance(other, self._subclass):
             other = other.to_array()
@@ -144,10 +104,63 @@ class Vec2(Vec):
         return self._vector[item]
 
 
-class Vec3(Vec2):
+class Vec2(Vec):
+    def __init__(self, x=None, y=0):
 
-    def __init__(self, x=None, y=1., z=1.):
-        super().__init__(sub_class=Vec3)
+        self._set_subclass()
+
+        if x is None:
+            x = 1
+        self._x = x
+        self._y = y
+        self._vector = None
+        self._set_vec()
+
+    def _set_subclass(self):
+        self._subclass = Vec2
+
+    @property
+    def x(self):
+        return self._x
+
+    @property
+    def y(self):
+        return self._y
+
+    def _set_vec(self):
+        self._vector = np.array([self._x, self._y], dtype=np.float64)
+
+    def to_array(self):
+        return self._vector
+
+    def _set_xy(self):
+        self._x = self._vector[0]
+        self._y = self._vector[1]
+
+    def _set_xy_and_more(self, *args, **kwargs):
+        self._set_xy()
+
+    def angle_between(self, v2):
+        return np.arccos(np.dot(
+            self.to_array() / get_norm(self.to_array()),
+            v2 / get_norm(v2)
+        ))
+
+    def _new(self, x, y):
+        return Vec2(x, y)
+
+    def normalise(self):
+        L = self.norm()
+        self._x /= L
+        self._y /= L
+        self._set_vec()
+        return self
+
+
+class Vec3(Vec):
+
+    def __init__(self, x=None, y=0, z=0):
+        self._set_subclass()
         if issubclass(type(x), (np.ndarray, list, tuple)):
             self._x = x[0]
             self._y = x[1]
@@ -162,6 +175,17 @@ class Vec3(Vec2):
         self._vector = None
         self._set_vec()
 
+    def _set_subclass(self):
+        self._subclass = Vec3
+
+    @property
+    def x(self):
+        return self._x
+
+    @property
+    def y(self):
+        return self._y
+
     @property
     def z(self):
         return self._z
@@ -204,8 +228,6 @@ class Vec3(Vec2):
         self._set_vec()
         return self
 
-
-
     def rotate(self, angle, axis=(0, 0, 1)):
         q = Quaternion().set_from_axis_angle(axis, angle)
         self.apply_quaternion(q)
@@ -220,11 +242,10 @@ class Vec3(Vec2):
     def _new(self, x, y, z):
         return Vec3(x, y, z)
 
-
-    def copy(self):
-        obj = object.__new__(Vec3)
-        obj.__init__(*self._vector)
-        return obj
+    # def copy(self):
+    #     obj = object.__new__(Vec3)
+    #     obj.__init__(*self._vector)
+    #     return obj
 
 
 
